The number of Wynton users over time

users_over_time(file = NULL, since = "2017-01-01")

Arguments

file

A file with a single column of signup dates, or NULL. If NULL, then the Wynton LDAP server is queried.

since

Drop signup dates prior to this date.

Value

A tibble::tibble with columns date and total, total the cumulative sum based on date occurances.

Examples

library(dplyr)
#> 
#> Attaching package: ‘dplyr’
#> The following objects are masked from ‘package:stats’:
#> 
#>     filter, lag
#> The following objects are masked from ‘package:base’:
#> 
#>     intersect, setdiff, setequal, union

pathname <- system.file("exdata", "ldap_wynton_dates.txt", package = "wyntonquery")

signups <- users_over_time(pathname)
print(head(signups))
#> # A tibble: 6 × 2
#>   date       total
#>   <date>     <int>
#> 1 2017-02-21     8
#> 2 2017-04-25     9
#> 3 2017-05-23    10
#> 4 2017-07-04    11
#> 5 2017-08-10    12
#> 6 2017-10-23    13
print(tail(signups))
#> # A tibble: 6 × 2
#>   date       total
#>   <date>     <int>
#> 1 2026-07-28   968
#> 2 2026-07-29   969
#> 3 2026-07-30   970
#> 4 2026-08-04   971
#> 5 2026-08-04   972
#> 6 2026-08-05   973

## Summarize by year and month
signups <- mutate(signups, year = format(date, "%Y"))

## Signups per calendar year
signups <- mutate(signups, month = format(date, "%m"))
signups <- group_by(signups, year)
signups_per_year <- count(signups, name = "change")
signups_end_of_year <- filter(signups, date == max(date), total == max(total))
signups_per_year <- left_join(signups_per_year, signups_end_of_year)
#> Joining with `by = join_by(year)`
signups_per_year <- select(signups_per_year, year, change, total, per = date)
print(signups_per_year, n = Inf)
#> # A tibble: 10 × 4
#> # Groups:   year [10]
#>    year  change total per       
#>    <chr>  <int> <int> <date>    
#>  1 2017      12    19 2017-12-12
#>  2 2018      13    32 2018-11-30
#>  3 2019      58    90 2019-12-11
#>  4 2020      61   151 2020-12-16
#>  5 2021      76   227 2021-12-18
#>  6 2022      93   320 2022-12-06
#>  7 2023     103   423 2023-12-22
#>  8 2024     176   599 2024-12-28
#>  9 2025     224   823 2025-12-23
#> 10 2026     150   973 2026-08-05

## Signups per calendar month
signups <- group_by(signups, year, month)
signups_per_month <- count(signups, name = "change")
signups_end_of_month <- filter(signups, date == max(date), total == max(total))
signups_per_month <- left_join(signups_per_month, signups_end_of_month)
#> Joining with `by = join_by(year, month)`
signups_per_month <- select(signups_per_month, year, month, change, total, per = date)
print(signups_per_month, n = Inf)
#> # A tibble: 107 × 5
#> # Groups:   year, month [107]
#>     year  month change total per       
#>     <chr> <chr>  <int> <int> <date>    
#>   1 2017  02         1     8 2017-02-21
#>   2 2017  04         1     9 2017-04-25
#>   3 2017  05         1    10 2017-05-23
#>   4 2017  07         1    11 2017-07-04
#>   5 2017  08         1    12 2017-08-10
#>   6 2017  10         1    13 2017-10-23
#>   7 2017  11         4    17 2017-11-21
#>   8 2017  12         2    19 2017-12-12
#>   9 2018  01         1    20 2018-01-26
#>  10 2018  02         2    22 2018-02-26
#>  11 2018  03         1    23 2018-03-22
#>  12 2018  05         2    25 2018-05-14
#>  13 2018  07         1    26 2018-07-18
#>  14 2018  08         2    28 2018-08-24
#>  15 2018  09         3    31 2018-09-07
#>  16 2018  11         1    32 2018-11-30
#>  17 2019  02         8    40 2019-02-21
#>  18 2019  03        15    55 2019-03-22
#>  19 2019  04         9    64 2019-04-30
#>  20 2019  05         6    70 2019-05-28
#>  21 2019  06         4    74 2019-06-30
#>  22 2019  07         1    75 2019-07-29
#>  23 2019  08         4    79 2019-08-26
#>  24 2019  09         2    81 2019-09-19
#>  25 2019  10         3    84 2019-10-31
#>  26 2019  11         5    89 2019-11-26
#>  27 2019  12         1    90 2019-12-11
#>  28 2020  01         6    96 2020-01-29
#>  29 2020  02         4   100 2020-02-29
#>  30 2020  03         5   105 2020-03-25
#>  31 2020  04         4   109 2020-04-20
#>  32 2020  05         6   115 2020-05-20
#>  33 2020  06         1   116 2020-06-02
#>  34 2020  07         7   123 2020-07-21
#>  35 2020  08         9   132 2020-08-31
#>  36 2020  09         5   137 2020-09-21
#>  37 2020  10         5   142 2020-10-30
#>  38 2020  11         7   149 2020-11-19
#>  39 2020  12         2   151 2020-12-16
#>  40 2021  01         4   155 2021-01-25
#>  41 2021  02         6   161 2021-02-26
#>  42 2021  03         4   165 2021-03-23
#>  43 2021  04         4   169 2021-04-27
#>  44 2021  05         4   173 2021-05-21
#>  45 2021  06         7   180 2021-06-30
#>  46 2021  07         4   184 2021-07-27
#>  47 2021  08         9   193 2021-08-30
#>  48 2021  09        11   204 2021-09-30
#>  49 2021  10        11   215 2021-10-27
#>  50 2021  11         5   220 2021-11-25
#>  51 2021  12         7   227 2021-12-18
#>  52 2022  01         8   235 2022-01-30
#>  53 2022  02         8   243 2022-02-26
#>  54 2022  03         8   251 2022-03-31
#>  55 2022  04         3   254 2022-04-27
#>  56 2022  05         7   261 2022-05-27
#>  57 2022  06         4   265 2022-06-29
#>  58 2022  07         7   272 2022-07-27
#>  59 2022  08         5   277 2022-08-31
#>  60 2022  09        23   300 2022-09-24
#>  61 2022  10        11   311 2022-10-25
#>  62 2022  11         8   319 2022-11-23
#>  63 2022  12         1   320 2022-12-06
#>  64 2023  01         7   327 2023-01-31
#>  65 2023  02         4   331 2023-02-24
#>  66 2023  03         6   337 2023-03-13
#>  67 2023  04         5   342 2023-04-26
#>  68 2023  05         6   348 2023-05-10
#>  69 2023  06        10   358 2023-06-30
#>  70 2023  07         6   364 2023-07-29
#>  71 2023  08        11   375 2023-08-29
#>  72 2023  09        27   402 2023-09-30
#>  73 2023  10        10   412 2023-10-24
#>  74 2023  11         9   421 2023-11-29
#>  75 2023  12         2   423 2023-12-22
#>  76 2024  01        15   438 2024-01-31
#>  77 2024  02        14   452 2024-02-29
#>  78 2024  03         6   458 2024-03-27
#>  79 2024  04        16   474 2024-04-24
#>  80 2024  05        11   485 2024-05-29
#>  81 2024  06        14   499 2024-06-28
#>  82 2024  07        13   512 2024-07-27
#>  83 2024  08        14   526 2024-08-31
#>  84 2024  09        35   561 2024-09-27
#>  85 2024  10        16   577 2024-10-31
#>  86 2024  11         4   581 2024-11-22
#>  87 2024  12        18   599 2024-12-28
#>  88 2025  01        14   613 2025-01-31
#>  89 2025  02        15   628 2025-02-28
#>  90 2025  03         6   634 2025-03-21
#>  91 2025  04         6   640 2025-04-29
#>  92 2025  05        12   652 2025-05-28
#>  93 2025  06        11   663 2025-06-21
#>  94 2025  07        24   687 2025-07-30
#>  95 2025  08        27   714 2025-08-29
#>  96 2025  09        38   752 2025-09-30
#>  97 2025  10        39   791 2025-10-30
#>  98 2025  11        21   812 2025-11-27
#>  99 2025  12        11   823 2025-12-23
#> 100 2026  01        29   852 2026-01-29
#> 101 2026  02        31   883 2026-02-24
#> 102 2026  03        19   902 2026-03-24
#> 103 2026  04        18   920 2026-04-23
#> 104 2026  05         7   927 2026-05-30
#> 105 2026  06        19   946 2026-06-26
#> 106 2026  07        24   970 2026-07-30
#> 107 2026  08         3   973 2026-08-05


if (require("ggplot2", quietly = TRUE)) {
  gg <- ggplot(signups, aes(date, total)) + geom_line(linewidth = 2.0)
  gg <- gg + xlab("") + ylab("Number of users")
  gg <- gg + theme(text = element_text(size = 20))
  print(gg)
}