The number of Wynton users over time

users_over_time(file = NULL, since = "2017-01-01")

Arguments

file

A file with a single column of signup dates, or NULL. If NULL, then the Wynton LDAP server is queried.

since

Drop signup dates prior to this date.

Value

A tibble::tibble with columns date and total, total the cumulative sum based on date occurances.

Examples

library(dplyr)
#> 
#> Attaching package: ‘dplyr’
#> The following objects are masked from ‘package:stats’:
#> 
#>     filter, lag
#> The following objects are masked from ‘package:base’:
#> 
#>     intersect, setdiff, setequal, union

pathname <- system.file("exdata", "ldap_wynton_dates.txt", package = "wyntonquery")

signups <- users_over_time(pathname)
print(head(signups))
#> # A tibble: 6 × 2
#>   date       total
#>   <date>     <int>
#> 1 2017-02-21    10
#> 2 2017-04-25    11
#> 3 2017-05-23    12
#> 4 2017-07-04    13
#> 5 2017-08-10    14
#> 6 2017-08-11    15
print(tail(signups))
#> # A tibble: 6 × 2
#>   date       total
#>   <date>     <int>
#> 1 2026-05-27   985
#> 2 2026-05-27   986
#> 3 2026-05-30   987
#> 4 2026-06-02   988
#> 5 2026-06-02   989
#> 6 2026-06-02   990

## Summarize by year and month
signups <- mutate(signups, year = format(date, "%Y"))

## Signups per calendar year
signups <- mutate(signups, month = format(date, "%m"))
signups <- group_by(signups, year)
signups_per_year <- count(signups, name = "change")
signups_end_of_year <- filter(signups, date == max(date), total == max(total))
signups_per_year <- left_join(signups_per_year, signups_end_of_year)
#> Joining with `by = join_by(year)`
signups_per_year <- select(signups_per_year, year, change, total, per = date)
print(signups_per_year, n = Inf)
#> # A tibble: 10 × 4
#> # Groups:   year [10]
#>    year  change total per       
#>    <chr>  <int> <int> <date>    
#>  1 2017      14    23 2017-12-12
#>  2 2018      13    36 2018-11-30
#>  3 2019      61    97 2019-12-11
#>  4 2020      63   160 2020-12-16
#>  5 2021      78   238 2021-12-18
#>  6 2022     100   338 2022-12-21
#>  7 2023     103   441 2023-12-22
#>  8 2024     186   627 2024-12-28
#>  9 2025     252   879 2025-12-23
#> 10 2026     111   990 2026-06-02

## Signups per calendar month
signups <- group_by(signups, year, month)
signups_per_month <- count(signups, name = "change")
signups_end_of_month <- filter(signups, date == max(date), total == max(total))
signups_per_month <- left_join(signups_per_month, signups_end_of_month)
#> Joining with `by = join_by(year, month)`
signups_per_month <- select(signups_per_month, year, month, change, total, per = date)
print(signups_per_month, n = Inf)
#> # A tibble: 105 × 5
#> # Groups:   year, month [105]
#>     year  month change total per       
#>     <chr> <chr>  <int> <int> <date>    
#>   1 2017  02         1    10 2017-02-21
#>   2 2017  04         1    11 2017-04-25
#>   3 2017  05         1    12 2017-05-23
#>   4 2017  07         1    13 2017-07-04
#>   5 2017  08         2    15 2017-08-11
#>   6 2017  10         1    16 2017-10-23
#>   7 2017  11         5    21 2017-11-21
#>   8 2017  12         2    23 2017-12-12
#>   9 2018  01         1    24 2018-01-26
#>  10 2018  02         2    26 2018-02-26
#>  11 2018  03         1    27 2018-03-22
#>  12 2018  05         2    29 2018-05-14
#>  13 2018  07         1    30 2018-07-18
#>  14 2018  08         2    32 2018-08-24
#>  15 2018  09         3    35 2018-09-07
#>  16 2018  11         1    36 2018-11-30
#>  17 2019  02         8    44 2019-02-21
#>  18 2019  03        15    59 2019-03-22
#>  19 2019  04        10    69 2019-04-30
#>  20 2019  05         6    75 2019-05-28
#>  21 2019  06         4    79 2019-06-30
#>  22 2019  07         1    80 2019-07-29
#>  23 2019  08         3    83 2019-08-26
#>  24 2019  09         3    86 2019-09-26
#>  25 2019  10         4    90 2019-10-31
#>  26 2019  11         5    95 2019-11-26
#>  27 2019  12         2    97 2019-12-11
#>  28 2020  01         5   102 2020-01-29
#>  29 2020  02         4   106 2020-02-29
#>  30 2020  03         5   111 2020-03-25
#>  31 2020  04         4   115 2020-04-20
#>  32 2020  05         6   121 2020-05-20
#>  33 2020  06         1   122 2020-06-02
#>  34 2020  07         8   130 2020-07-28
#>  35 2020  08        10   140 2020-08-31
#>  36 2020  09         6   146 2020-09-21
#>  37 2020  10         5   151 2020-10-30
#>  38 2020  11         7   158 2020-11-19
#>  39 2020  12         2   160 2020-12-16
#>  40 2021  01         5   165 2021-01-25
#>  41 2021  02         6   171 2021-02-26
#>  42 2021  03         5   176 2021-03-25
#>  43 2021  04         4   180 2021-04-27
#>  44 2021  05         5   185 2021-05-21
#>  45 2021  06         6   191 2021-06-30
#>  46 2021  07         4   195 2021-07-27
#>  47 2021  08         9   204 2021-08-30
#>  48 2021  09        11   215 2021-09-30
#>  49 2021  10        11   226 2021-10-27
#>  50 2021  11         5   231 2021-11-25
#>  51 2021  12         7   238 2021-12-18
#>  52 2022  01         9   247 2022-01-30
#>  53 2022  02         9   256 2022-02-26
#>  54 2022  03         9   265 2022-03-31
#>  55 2022  04         4   269 2022-04-27
#>  56 2022  05         7   276 2022-05-27
#>  57 2022  06         5   281 2022-06-29
#>  58 2022  07         7   288 2022-07-27
#>  59 2022  08         6   294 2022-08-31
#>  60 2022  09        22   316 2022-09-24
#>  61 2022  10        13   329 2022-10-26
#>  62 2022  11         7   336 2022-11-23
#>  63 2022  12         2   338 2022-12-21
#>  64 2023  01         7   345 2023-01-31
#>  65 2023  02         3   348 2023-02-24
#>  66 2023  03         7   355 2023-03-21
#>  67 2023  04         4   359 2023-04-26
#>  68 2023  05         6   365 2023-05-10
#>  69 2023  06        10   375 2023-06-30
#>  70 2023  07         6   381 2023-07-29
#>  71 2023  08        12   393 2023-08-29
#>  72 2023  09        27   420 2023-09-30
#>  73 2023  10        10   430 2023-10-24
#>  74 2023  11         9   439 2023-11-29
#>  75 2023  12         2   441 2023-12-22
#>  76 2024  01        15   456 2024-01-31
#>  77 2024  02        12   468 2024-02-29
#>  78 2024  03         6   474 2024-03-27
#>  79 2024  04        17   491 2024-04-24
#>  80 2024  05        12   503 2024-05-31
#>  81 2024  06        14   517 2024-06-28
#>  82 2024  07        17   534 2024-07-27
#>  83 2024  08        14   548 2024-08-31
#>  84 2024  09        36   584 2024-09-27
#>  85 2024  10        17   601 2024-10-31
#>  86 2024  11         7   608 2024-11-22
#>  87 2024  12        19   627 2024-12-28
#>  88 2025  01        17   644 2025-01-31
#>  89 2025  02        15   659 2025-02-28
#>  90 2025  03         6   665 2025-03-21
#>  91 2025  04         7   672 2025-04-29
#>  92 2025  05        16   688 2025-05-28
#>  93 2025  06        19   707 2025-06-27
#>  94 2025  07        30   737 2025-07-30
#>  95 2025  08        26   763 2025-08-29
#>  96 2025  09        39   802 2025-09-30
#>  97 2025  10        41   843 2025-10-30
#>  98 2025  11        22   865 2025-11-27
#>  99 2025  12        14   879 2025-12-23
#> 100 2026  01        31   910 2026-01-30
#> 101 2026  02        32   942 2026-02-24
#> 102 2026  03        20   962 2026-03-24
#> 103 2026  04        18   980 2026-04-23
#> 104 2026  05         7   987 2026-05-30
#> 105 2026  06         3   990 2026-06-02


if (require("ggplot2", quietly = TRUE)) {
  gg <- ggplot(signups, aes(date, total)) + geom_line(linewidth = 2.0)
  gg <- gg + xlab("") + ylab("Number of users")
  gg <- gg + theme(text = element_text(size = 20))
  print(gg)
}