The number of Wynton users over time

users_over_time(file = NULL, since = "2017-01-01")

Arguments

file

A file with a single column of signup dates, or NULL. If NULL, then the Wynton LDAP server is queried.

since

Drop signup dates prior to this date.

Value

A tibble::tibble with columns date and total, total the cumulative sum based on date occurances.

Examples

library(dplyr)
#> 
#> Attaching package: ‘dplyr’
#> The following objects are masked from ‘package:stats’:
#> 
#>     filter, lag
#> The following objects are masked from ‘package:base’:
#> 
#>     intersect, setdiff, setequal, union

pathname <- system.file("exdata", "ldap_wynton_dates.txt", package = "wyntonquery")

signups <- users_over_time(pathname)
print(head(signups))
#> # A tibble: 6 × 2
#>   date       total
#>   <date>     <int>
#> 1 2017-02-21    10
#> 2 2017-04-25    11
#> 3 2017-05-23    12
#> 4 2017-07-04    13
#> 5 2017-08-10    14
#> 6 2017-08-11    15
print(tail(signups))
#> # A tibble: 6 × 2
#>   date       total
#>   <date>     <int>
#> 1 2026-03-20  1027
#> 2 2026-03-24  1028
#> 3 2026-04-01  1029
#> 4 2026-04-01  1030
#> 5 2026-04-02  1031
#> 6 2026-04-04  1032

## Summarize by year and month
signups <- mutate(signups, year = format(date, "%Y"))

## Signups per calendar year
signups <- mutate(signups, month = format(date, "%m"))
signups <- group_by(signups, year)
signups_per_year <- count(signups, name = "change")
signups_end_of_year <- filter(signups, date == max(date), total == max(total))
signups_per_year <- left_join(signups_per_year, signups_end_of_year)
#> Joining with `by = join_by(year)`
signups_per_year <- select(signups_per_year, year, change, total, per = date)
print(signups_per_year, n = Inf)
#> # A tibble: 10 × 4
#> # Groups:   year [10]
#>    year  change total per       
#>    <chr>  <int> <int> <date>    
#>  1 2017      14    23 2017-12-12
#>  2 2018      14    37 2018-11-30
#>  3 2019      60    97 2019-12-11
#>  4 2020      67   164 2020-12-22
#>  5 2021      84   248 2021-12-18
#>  6 2022     107   355 2022-12-21
#>  7 2023     112   467 2023-12-22
#>  8 2024     193   660 2024-12-28
#>  9 2025     280   940 2025-12-23
#> 10 2026      92  1032 2026-04-04

## Signups per calendar month
signups <- group_by(signups, year, month)
signups_per_month <- count(signups, name = "change")
signups_end_of_month <- filter(signups, date == max(date), total == max(total))
signups_per_month <- left_join(signups_per_month, signups_end_of_month)
#> Joining with `by = join_by(year, month)`
signups_per_month <- select(signups_per_month, year, month, change, total, per = date)
print(signups_per_month, n = Inf)
#> # A tibble: 103 × 5
#> # Groups:   year, month [103]
#>     year  month change total per       
#>     <chr> <chr>  <int> <int> <date>    
#>   1 2017  02         1    10 2017-02-21
#>   2 2017  04         1    11 2017-04-25
#>   3 2017  05         1    12 2017-05-23
#>   4 2017  07         1    13 2017-07-04
#>   5 2017  08         2    15 2017-08-11
#>   6 2017  10         1    16 2017-10-23
#>   7 2017  11         5    21 2017-11-21
#>   8 2017  12         2    23 2017-12-12
#>   9 2018  01         1    24 2018-01-26
#>  10 2018  02         2    26 2018-02-26
#>  11 2018  03         2    28 2018-03-29
#>  12 2018  05         2    30 2018-05-14
#>  13 2018  07         1    31 2018-07-18
#>  14 2018  08         2    33 2018-08-24
#>  15 2018  09         3    36 2018-09-07
#>  16 2018  11         1    37 2018-11-30
#>  17 2019  02        10    47 2019-02-21
#>  18 2019  03        15    62 2019-03-22
#>  19 2019  04         8    70 2019-04-30
#>  20 2019  05         6    76 2019-05-28
#>  21 2019  06         4    80 2019-06-30
#>  22 2019  07         1    81 2019-07-29
#>  23 2019  08         3    84 2019-08-26
#>  24 2019  09         2    86 2019-09-26
#>  25 2019  10         4    90 2019-10-31
#>  26 2019  11         5    95 2019-11-26
#>  27 2019  12         2    97 2019-12-11
#>  28 2020  01         6   103 2020-01-29
#>  29 2020  02         4   107 2020-02-29
#>  30 2020  03         5   112 2020-03-25
#>  31 2020  04         3   115 2020-04-20
#>  32 2020  05         6   121 2020-05-20
#>  33 2020  06         1   122 2020-06-02
#>  34 2020  07         9   131 2020-07-28
#>  35 2020  08        10   141 2020-08-31
#>  36 2020  09         7   148 2020-09-21
#>  37 2020  10         6   154 2020-10-30
#>  38 2020  11         7   161 2020-11-19
#>  39 2020  12         3   164 2020-12-22
#>  40 2021  01         6   170 2021-01-25
#>  41 2021  02         6   176 2021-02-26
#>  42 2021  03         5   181 2021-03-25
#>  43 2021  04         4   185 2021-04-27
#>  44 2021  05         6   191 2021-05-21
#>  45 2021  06         6   197 2021-06-30
#>  46 2021  07         4   201 2021-07-27
#>  47 2021  08         9   210 2021-08-30
#>  48 2021  09        12   222 2021-09-30
#>  49 2021  10        12   234 2021-10-27
#>  50 2021  11         6   240 2021-11-25
#>  51 2021  12         8   248 2021-12-18
#>  52 2022  01         9   257 2022-01-30
#>  53 2022  02         8   265 2022-02-26
#>  54 2022  03        11   276 2022-03-31
#>  55 2022  04         4   280 2022-04-27
#>  56 2022  05         9   289 2022-05-27
#>  57 2022  06         5   294 2022-06-25
#>  58 2022  07         7   301 2022-07-27
#>  59 2022  08         7   308 2022-08-31
#>  60 2022  09        23   331 2022-09-24
#>  61 2022  10        14   345 2022-10-26
#>  62 2022  11         8   353 2022-11-23
#>  63 2022  12         2   355 2022-12-21
#>  64 2023  01         8   363 2023-01-31
#>  65 2023  02         4   367 2023-02-24
#>  66 2023  03         7   374 2023-03-21
#>  67 2023  04        10   384 2023-04-26
#>  68 2023  05         5   389 2023-05-10
#>  69 2023  06        10   399 2023-06-30
#>  70 2023  07         6   405 2023-07-29
#>  71 2023  08        13   418 2023-08-29
#>  72 2023  09        27   445 2023-09-30
#>  73 2023  10        11   456 2023-10-24
#>  74 2023  11         9   465 2023-11-29
#>  75 2023  12         2   467 2023-12-22
#>  76 2024  01        11   478 2024-01-31
#>  77 2024  02        14   492 2024-02-29
#>  78 2024  03         8   500 2024-03-27
#>  79 2024  04        21   521 2024-04-24
#>  80 2024  05        12   533 2024-05-31
#>  81 2024  06        15   548 2024-06-28
#>  82 2024  07        19   567 2024-07-27
#>  83 2024  08        14   581 2024-08-31
#>  84 2024  09        39   620 2024-09-28
#>  85 2024  10        15   635 2024-10-31
#>  86 2024  11         6   641 2024-11-22
#>  87 2024  12        19   660 2024-12-28
#>  88 2025  01        16   676 2025-01-31
#>  89 2025  02        16   692 2025-02-28
#>  90 2025  03        12   704 2025-03-25
#>  91 2025  04        17   721 2025-04-30
#>  92 2025  05        20   741 2025-05-28
#>  93 2025  06        22   763 2025-06-30
#>  94 2025  07        30   793 2025-07-30
#>  95 2025  08        29   822 2025-08-29
#>  96 2025  09        39   861 2025-09-30
#>  97 2025  10        41   902 2025-10-30
#>  98 2025  11        24   926 2025-11-27
#>  99 2025  12        14   940 2025-12-23
#> 100 2026  01        32   972 2026-01-30
#> 101 2026  02        33  1005 2026-02-24
#> 102 2026  03        23  1028 2026-03-24
#> 103 2026  04         4  1032 2026-04-04


if (require("ggplot2", quietly = TRUE)) {
  gg <- ggplot(signups, aes(date, total)) + geom_line(linewidth = 2.0)
  gg <- gg + xlab("") + ylab("Number of users")
  gg <- gg + theme(text = element_text(size = 20))
  print(gg)
}